Monnik
======

Monnik is a Python library that makes it easier to query and interact with the 
REST API's provided by `Agentschap Onroerend Erfgoed <https://www.onroerenderfgoed.be>`_, 
such as the `Inventaris Onroerend Erfgoed <https://inventaris.onroerenderfgoed.be>`_.

.. image:: https://app.travis-ci.com/onroerenderfgoed/monnik.svg?branch=master
    :target: https://app.travis-ci.com/onroerenderfgoed/monnik
.. image:: https://coveralls.io/repos/onroerenderfgoed/monnik/badge.svg?branch=master
        :target: https://coveralls.io/github/onroerenderfgoed/monnik?branch=master
.. image:: https://badge.fury.io/py/monnik.svg
        :target: http://badge.fury.io/py/monnik
